# Description

Cases for low Reynolds number bubbly pipe flows (Re=750) in OpenFOAM have been
set-up with the baseline model set developed at HZDR. The models are validated with 
experimental data of Kim et al. (2016) [^1].

# Technical Information

The cases contain the experimental data in the validation folder. By executing the 
Allrun script inside the case folder the simulation is run and plots generated
comparing computed results against the experimental data.

# Pre-Processing

In order to simplify the CFD setup an axi-symmetric geometry (2D-wedge of
2.5 deg.) of the pipe is simulated. The CFD setup further assumes that both phases
enter from the same inlet with an inlet phase fraction derived from the experiment
and zero relative velocity between the phases.

# Post-Processing

See information inside cases.

## Data Validation

| Field     | Validation   | Reference                           |
| :-------: | :----------: | :---------------------------------: |
| alpha     | alpha.dat    | line_alpha.air_k.water.xy           |
| k.water   | liqKe.dat    | line_alpha.air_k.water.xy           |
| U.water   | liqVel.dat   | line_U.air_U.water.xy               |
| U.air     | gasVel.dat   | line_U.air_U.water.xy               |

# Keywords

pipe, circular-cross-section, constant-cross-section, bottom-injection,
vertical-upward, co-current, air-water, bubbly-flow, one-gas, fixed-bubble-size,
monodisperse, incompressible, tap-water, steady-state, fully-developed,
isothermal, 2D-wedge, two-phase-inlet, pressure-outlet

# Additional Remarks

* Constant diameterModel
* Constant physical properties at standard conditions
* Adjusted values for the superficial velocity J_G were computed from the profiles measured at level z/D=42
* Comparing adjusted J_G values to reported values in Kim et al. 2016 [^1] it seems values in Table 1 are erroneous
* Value for J_L was fixed at 1.88E-2 m/s as given by the experiment
* Zero velocity difference between phases at inlet, i.e. alpha=J_G/(J_G+J_L), U_G=U_L=J_G+J_L
* Averaged bubble diameters given by experiment
* 1% turbulence intensity is prescribed at the inlet, and the turbulence length scale assumed to be 10% of the pipe diameter
* Quantities measured over entire pipe diameter (negative and positive r), but validation data averaged over pipe radius

# Literature

[^1]: Kim, M., Lee, J.H., Park, H. 2013. Study of Bubble-induced turbulence in upward
      laminar pipe flows measured with a two-phase particle image velocitmetry. Experiments in Fluids.
