g   = 9.81
d   = 1.
nuL = 0.2232

set linetype 1 lc rgb "red"  lw 3 dt 1 pt 7 ps 0.5
set linetype 2 lc rgb "blue" lw 3 dt 1

set grid
set key outside below

#---PNG---
set term pngcairo color enhanced size 800,600
FType = '.png'

#---bubbleProperties---
system("cat ../postProcessing/bubble/0/bubble.dat ../postProcessing/bubble/1/bubble.dat > ../postProcessing/bubble/bubble.dat")
FILE =      "../postProcessing/bubble/bubble.dat"
TOFFSET = 1

set xlabel  "t"
set xtics nomirror
set x2label  "t* = t g^{0.5} d^{-0.5}"
set x2tics
set link x2 via x*g**0.5*d**0.5 inverse x/(g**0.5*d**0.5)

set output  "bubblePosition".FType
unset title
set ylabel  "X_T d^{-1}"
plot FILE u ($1-TOFFSET):($4/d) w l ls 1 notitle

set output  "bubbleVelocity".FType
set ylabel  "U_T(gd)^{-0.5}"
plot FILE u ($1-TOFFSET):($7/(g*d)**0.5) w l ls 1 notitle

set output  "bubbleRe".FType
RFILE =     "Balcazar2015/Re.dat"
set ylabel  "Re"
plot RFILE axis x2y1                 w l ls 2 t "Balcázar (2015)", \
     FILE  u ($1-TOFFSET):($7*d/nuL) w l ls 1 t "cipsaMultiphaseEulerFoam"

set output  "sphericity".FType
set ylabel  "sphericity"
plot FILE u ($1-TOFFSET):(($10<=1.1) ? $10 : 1/0) every 4 w l ls 1 notitle

unset x2label
unset x2tics
set xtics mirror

#---bubbleSurface---
LIST =      system("ls -1 ../postProcessing/bubbleSurface/ | sort -g")
NUM =       words(LIST)
TIMES(n) =  word(LIST,n)

FILE(n) =   "../postProcessing/bubbleSurface/".TIMES(n)."/bubble.raw
RFILE =     "Balcazar2015/shape.dat"

set xlabel  "x"
set xrange  [-0.7:0.7]
set ylabel  "z"
set yrange  [-0.5:0.5]
set size ratio -1
YTHRESHOLD = 0.05
ZTHRESHOLD = 10.9
RSCALE = 0.0048

do for [i=1:NUM] {

    unset output
    set term unknown
    plot FILE u 1:(($1 == TIMES(i)) ? ZPOS=$4 : 1/0)

    set term pngcairo color enhanced size 800,600
    set output  "shape_".sprintf("%03i", i+0).FType

    set title sprintf("t = %1.2f s", TIMES(i)-TOFFSET)

    plot RFILE   u (RSCALE*($1-278)):(RSCALE*(-$2+490))                                          w l ls 2        t "Balcázar (2015)", \
         FILE(i) u 1:(($3<=ZTHRESHOLD) && ($2>=-YTHRESHOLD) && ($2<=YTHRESHOLD) ? $3-ZPOS : 1/0) w p ls 1 ps 0.5 t "cipsaMultiphaseEulerFoam"
}
