# Description

Simulation (2D) set-up for WENKA test facility

The validation case MP3-23 considers isothermal supercritical counter-current
stratified flow in WENKA experiment with a Froude number of 2.36 and
Reynolds numbers of 12000 for water and 27000 for air (Stäbler, 2007).

The computational domain is based on ANSYS CFX simulations
by Höhne and Porombka (2018) and represents the rectangular test channel
of WENKA facility.

# Technical Information

* 2D
* 8000 mesh cells
* StrubeljTiselj drag formulation
* Partial elimination
* Interface compression
* Turbulence damping with kOmegaSSTItEgorov
    (formulation of Frederix et al., 2018)
  - Symmetric damping with delta = 7e-5 in both phases
  - No damping in water
* Interface indicator with interfaceIndicatorMethod: gradAlpha
* Field mapping at air and water inlets

# Pre-Processing

* setFields for air and water

# Post-Processing

FunctionObjects used at run time:
* residuals
* probes
* fieldAverage1
* verticalLine_235
* verticalLine_380
* verticalLine_235_Mean
* verticalLine_380_Mean


Bash script:
* Gnuplot script createGraphs.plt

Find all result files in the validation directory.
Commented are instructions to plot the mean fields if desired.


# Keywords

hybrid, stratified flow, turbulence damping

# Additional Remarks

* Field averaging
  - After initial 10 s transient, fields are averaged for additional 10 s.
* Approximate run time on 4 nodes in defq on hemera is 2.2 hours.
  - For testing, set shorter runs with endTime 5 s (~30 minutes), disable avg.

# Literature

Stäbler, T. D. (2007). Experimentelle Untersuchung und physikalische
Beschreibung der Schichtenströmung in horizontalen Kanälen. PhD Thesis.
https://elib.uni-stuttgart.de/handle/11682/1741

Höhne, T., & Porombka, P. (2018). Modelling horizontal two-phase flows using
generalized models. Annals of Nuclear Energy, 111, 311-316.
